Crate cloudconvert

source ·
Creating a client

To create a Client using a bearer token, then create a job:

use cloudconvert::{Client, job};
let client = Client::default_client("your_bearer_token");
client.call(job::Create{
    tasks: todo!(),
    tag: Some("your_tag".into()),
    webhook_url: None,
}).await;

Jobs

Jobs can be crated using the job::Create API call. Jobs consist of a number of named tasks.

Tasks

A task::Task enum represents one of the following tasks:

Import tasks

Processing tasks

Export tasks

Pre-made jobs

  • ImportConvertExport: An API call (underneath, job::Create) which creates a job consisting of an import task, convert task, then export task.

Webhooks

Tools for verifying and parsing webhooks can be found within the webhook module.

Modules

  • Types for creating and viewing jobs.
  • Types related to managing tasks. See the crate level docs for a nice list of available tasks.
  • Tools for verifying and parsing webhook calls.

Structs

Enums

Traits

  • The trait implemented by all the API calls. Execute these using a Client.

Type Aliases