pub struct ExportOpenStack<'a> {
pub input: Input<'a, 'a>,
pub auth_url: Cow<'a, str>,
pub username: Cow<'a, str>,
pub password: Cow<'a, str>,
pub region: Cow<'a, str>,
pub container: Cow<'a, str>,
pub tenant_name: Option<Cow<'a, str>>,
pub file: Option<Cow<'a, str>>,
pub file_prefix: Option<Cow<'a, str>>,
}Expand description
Export files to OpenStack Object Storage (Swift)
Fields
input: Input<'a, 'a>The ID of the task, or tasks, to export.
auth_url: Cow<'a, str>username: Cow<'a, str>password: Cow<'a, str>region: Cow<'a, str>container: Cow<'a, str>tenant_name: Option<Cow<'a, str>>file: Option<Cow<'a, str>>file_prefix: Option<Cow<'a, str>>Implementations
Sourceimpl<'a> ExportOpenStack<'a>
impl<'a> ExportOpenStack<'a>
Sourcepub fn to_job_task(&self) -> Result<Value>
pub fn to_job_task(&self) -> Result<Value>
Convert a job to an object to be included in a job call.
This includes the fields of the task, with an additional "operation" field,
containing the operation name.